.. _environment:

Environment
===========

Variables
---------

.. list-table:: Environment Variables
   :widths: 25 25 50
   :header-rows: 1

   * - Variable
     - Default
     - Values
   * - PORT
     - 8080
     -
   * - HOST
     - 0.0.0.0
     -
   * - PROXY_PATH
     -
     -
   * - ORIGIN
     - \*
     -
   * - OPENAI_API_KEY
     -
     -
   * - DATA_PATH
     - ./data
     -
